@@ -63,7 +63,7 @@ double PInt2e_base<in_tN>::cal_I(double in_g,const std::vector<int> &in_n){
   nnn[0] =1;  nnn[1] =1;  nnn[2] =1;  nnn[3] =2;  nnn[4] =3; nnn[5] =8;
   nnn[6] =15; nnn[7] =48; nnn[8] =105;nnn[9] =384;nnn[10] =945;
   return pow((2*in_g/M_PI),3.0/4.0)*pow(4*in_g,(in_n[0]+in_n[1]+in_n[2])/2.0)/
-             sqrt(nnn[2*in_n[0]]*nnn[2*in_n[1]]*nnn[2*in_n[2]]);
+             sqrt((double)nnn[2*in_n[0]]*nnn[2*in_n[1]]*nnn[2*in_n[2]]);
 }
 
 
