@@ -38,12 +38,11 @@ void Check(int check){
 
 int main(int argc,char *argv[]){
 
-  int N_process=1;
   int process_num=0;
   #ifdef USE_MPI_LOTUS
   MPI_Init(&argc,&argv);
   Util_MPI::set_MPI_COMM_LOTUS();
-  N_process   = Util_MPI::get_mpi_size();
+  int N_process   = Util_MPI::get_mpi_size();
   process_num = Util_MPI::get_mpi_rank();
   struct utsname uts;
   uname(&uts);
