@@ -416,18 +416,28 @@ class td_scf(unittest.TestCase):
     self.fun_scf_sub_ediis(filename_d, exact_v, 0)
 
 
-
-
-if __name__ == "__main__":
+def run_test():
   try:
     from mpi4py import MPI
     lotus_core_hpp.Util_MPI.set_MPI_COMM_LOTUS()
+    process_num = lotus_core_hpp.Util_MPI.get_mpi_rank()
   except:
     lotus_core_hpp.Util_MPI.set_MPI_COMM_LOTUS()
     process_num = lotus_core_hpp.Util_MPI.get_mpi_rank()
     if process_num==0: print " mpi4py is not installed"
 
-  unittest.main(exit=False)
+  if process_num==0: print " ##### test6.py #####"
+  suite = unittest.TestLoader().loadTestsFromTestCase(td_scf)
+  try:
+    import xmlrunner
+    testRunner = xmlrunner.XMLTestRunner()
+  except:
+    if process_num==0: print " unittest-xml-reporting is not installed"
+    testRunner = unittest.TextTestRunner()
 
- 
+  unittest.TextTestRunner().run(suite)
+
+
+if __name__ == "__main__":
+  run_test()
 
